/*
 *   ORXONOX - the hottest 3D action shooter ever to exist
 *                    > www.orxonox.net <
 *
 *
 *   License notice:
 *
 *   This program is free software; you can redistribute it and/or
 *   modify it under the terms of the GNU General Public License
 *   as published by the Free Software Foundation; either version 2
 *   of the License, or (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 *   Author:
 *      Leo Merholz
 *      Pascal Schärli
 *
 *      Co-authors:
 *      ...
 */

#include "PacmanHUDinfo.h"

#include "core/CoreIncludes.h"
#include "core/XMLPort.h"
#include "util/Convert.h"

namespace orxonox
{
    RegisterClass(PacmanHUDinfo);

    PacmanHUDinfo::PacmanHUDinfo(Context* context) : OverlayText(context)
    {
        RegisterObject(PacmanHUDinfo);

        this->PacmanGame = nullptr;
        this->bShowPoints_ = false;
        this->bShowMessage_ = false;
        this->messageID = 0;
    }

    void PacmanHUDinfo::XMLPort(Element& xmlelement, XMLPort::Mode mode)
    {
        SUPER(PacmanHUDinfo, XMLPort, xmlelement, mode);

        XMLPortParam(PacmanHUDinfo, "showpoints",    setShowPoints,    getShowPoints,    xmlelement, mode).defaultValues(false);
        XMLPortParam(PacmanHUDinfo, "showmessage",   setShowMessage,   getShowMessage,   xmlelement, mode).defaultValues(false);
        XMLPortParam(PacmanHUDinfo, "messageID",     setMessageID,     getMessageID,     xmlelement, mode).defaultValues(0);
       
    
    }

    void PacmanHUDinfo::tick(float dt)
    {
        SUPER(PacmanHUDinfo, tick, dt);

        if (this->PacmanGame)
        {
                if(this->bShowPoints_){
                    const std::string& points = "Score: "+multi_cast<std::string>(this->PacmanGame->getPoints());
                    setTextSize(0.04);
                    this->setCaption(points);
                }
        }
    }    

    void PacmanHUDinfo::changedOwner()
    {
        SUPER(PacmanHUDinfo, changedOwner);

        if (this->getOwner() && this->getOwner()->getGametype())
        {
            this->PacmanGame = orxonox_cast<Pacman*>(this->getOwner()->getGametype());
        }
        else
        {
            this->PacmanGame = nullptr;
        }
    }
}